@@ -47,61 +47,6 @@ fit1 <- grpreg(X, yy, group, penalty="gel", family="binomial")
 fit2 <- grpreg(X, yy, group, penalty="gel", family="binomial", lambda=fit1$lambda)
 check(fit1$beta, fit2$beta)
 
-.test = "grpreg handles constant columns"
-n <- 50
-group <- rep(0:3,4:1)
-p <- length(group)
-X <- matrix(rnorm(n*p),ncol=p)
-X[,group==2] <- 0
-y <- rnorm(n)
-yy <- y > 0
-par(mfrow=c(3,3))
-fit <- grpreg(X, y, group, penalty="grLasso"); plot(fit)
-fit <- grpreg(X, y, group, penalty="cMCP"); plot(fit)
-fit <- gBridge(X, y, group); plot(fit)
-fit <- grpreg(X, yy, group, penalty="grLasso", family="binomial"); plot(fit)
-fit <- grpreg(X, yy, group, penalty="cMCP", family="binomial"); plot(fit); fit$beta[,100]
-fit <- gBridge(X, yy, group, family="binomial"); plot(fit); fit$beta[,100]
-fit <- grpreg(X, yy, group, penalty="grLasso", family="poisson"); plot(fit)
-fit <- grpreg(X, yy, group, penalty="cMCP", family="poisson"); plot(fit); fit$beta[,100]
-fit <- gBridge(X, yy, group, family="poisson"); plot(fit); fit$beta[,100]
-cvfit <- cv.grpreg(X, y, group, penalty="grLasso")
-cvfit <- cv.grpreg(X, y, group, penalty="gel")
-
-.test = "grpreg handles groups of non-full rank"
-n <- 50
-group <- rep(0:3,4:1)
-p <- length(group)
-X <- matrix(rnorm(n*p),ncol=p)
-X[,7] <- X[,6]
-y <- rnorm(n)
-yy <- y > 0
-par(mfrow=c(2,3))
-fit <- grpreg(X, y, group, penalty="grLasso"); plot(fit)
-fit <- grpreg(X, y, group, penalty="cMCP"); plot(fit)
-fit <- grpreg(X, yy, group, penalty="grLasso", family="binomial"); plot(fit)
-fit <- grpreg(X, yy, group, penalty="cMCP", family="binomial"); plot(fit)
-fit <- grpreg(X, yy, group, penalty="grLasso", family="poisson"); plot(fit)
-fit <- grpreg(X, yy, group, penalty="cMCP", family="poisson"); plot(fit)
-cvfit <- cv.grpreg(X, y, group, penalty="grLasso")
-cvfit <- cv.grpreg(X, y, group, penalty="gel")
-
-.test = "grpreg out-of-order groups"
-n <- 50
-group <- rep(0:3,4:1)
-ind <- sample(1:length(group))
-p <- length(group)
-X <- matrix(rnorm(n*p),ncol=p)
-X[,group==2] <- 0
-y <- rnorm(n)
-yy <- y > 0
-fit1 <- grpreg(X, y, group, penalty="grLasso")
-fit2 <- grpreg(X[,ind], y, group[ind], penalty="grLasso")
-b1 <- coef(fit1)[-1,][ind,]
-b2 <- coef(fit2)[-1,]
-check(b1, b2, tol=0.01)
-cvfit <- cv.grpreg(X, y, group, penalty="grLasso")
-
 .test = "grpreg named groups"
 n <- 50
 group1 <- rep(0:3,4:1)
@@ -116,19 +61,6 @@ fit2 <- grpreg(X, y, group2, penalty="grLasso")
 check(coef(fit1), coef(fit2), tol=0.001)
 cvfit <- cv.grpreg(X, y, group, penalty="grLasso")
 
-.test = "grpreg out-of-order groups with constant columns"
-n <- 50
-group <- rep(c(1,3,0,2),5:2)
-p <- length(group)
-X <- matrix(rnorm(n*p),ncol=p)
-X[,group==2] <- 0
-y <- rnorm(n)
-mle <- coef(lm(y~X))
-mle[!is.finite(mle)] <- 0
-grl <- coef(grpreg(X, y, group, penalty="grLasso", lambda.min=0, eps=1e-7), lambda=0)
-check(mle, grl, tol=0.01)
-cvfit <- cv.grpreg(X, y, group, penalty="grLasso")
-
 .test = "group.multiplier works"
 n <- 50
 p <- 11
