@@ -28,7 +28,7 @@ void gd_binomial(double *b, double *x, double *r, double *eta, int g, int *K1, i
   if (strcmp(penalty, "grLasso")==0) len = S(v * z_norm, lam1) / (v * (1 + lam2));
   if (strcmp(penalty, "grMCP")==0) len = F(v * z_norm, lam1, lam2, gamma) / v;
   if (strcmp(penalty, "grSCAD")==0) len = Fs(v * z_norm, lam1, lam2, gamma) / v;
-  if (len != 0 | a[K1[g]] != 0) {
+  if (len != 0 || a[K1[g]] != 0) {
     // If necessary, update b and r
     for (int j=K1[g]; j<K1[g+1]; j++) {
       b[l*p+j] = len * z[j-K1[g]] / z_norm;
@@ -133,7 +133,7 @@ SEXP gdfit_binomial(SEXP X_, SEXP y_, SEXP penalty_, SEXP K1_, SEXP K0_, SEXP la
 	  nv = nv + (K1[g+1]-K1[g]);
 	}
       }
-      if (ng > gmax | nv > dfmax | tot_iter == max_iter) {
+      if (ng > gmax || nv > dfmax || tot_iter == max_iter) {
 	for (int ll=l; ll<L; ll++) INTEGER(iter)[ll] = NA_INTEGER;
         break;
       }
